@@ -9,7 +9,7 @@ from pathlib import Path
 if __name__ == "__main__":
     os.chdir(Path(__file__).parent)
     os.environ["CUSTOM_COMPILE_COMMAND"] = "requirements/compile.py"
-    os.environ.pop("PIP_REQUIRE_VIRTUALENV", None)
+    os.environ["PIP_REQUIRE_VIRTUALENV"] = "0"
     common_args = [
         "-m",
         "piptools",
